summaryrefslogtreecommitdiffstats
path: root/telephony
diff options
context:
space:
mode:
authorJonathan Basseri <misterikkit@google.com>2015-05-13 17:46:29 +0000
committerAndroid (Google) Code Review <android-gerrit@google.com>2015-05-13 17:46:32 +0000
commitc69cd0bf7586c57f9662955d798a2ae0eef6ee76 (patch)
treee988aa9e556b8d1beaa7f020dafdda15a0b07af1 /telephony
parent22fec2201f01222d61c84f536289fd1e8bb5a03f (diff)
parent4f9ad1678eca240afb5a2174dc35e4f0559312c3 (diff)
downloadframeworks_base-c69cd0bf7586c57f9662955d798a2ae0eef6ee76.zip
frameworks_base-c69cd0bf7586c57f9662955d798a2ae0eef6ee76.tar.gz
frameworks_base-c69cd0bf7586c57f9662955d798a2ae0eef6ee76.tar.bz2
Merge "Switching to PersistableBundle in carrier config API." into mnc-dev
Diffstat (limited to 'telephony')
-rw-r--r--telephony/java/android/telephony/CarrierConfigManager.java18
-rw-r--r--telephony/java/com/android/internal/telephony/ICarrierConfigLoader.aidl4
2 files changed, 11 insertions, 11 deletions
diff --git a/telephony/java/com/android/internal/telephony/ICarrierConfigLoader.aidl b/telephony/java/com/android/internal/telephony/ICarrierConfigLoader.aidl
index b5cdd9a..cb53f51 100644
--- a/telephony/java/com/android/internal/telephony/ICarrierConfigLoader.aidl
+++ b/telephony/java/com/android/internal/telephony/ICarrierConfigLoader.aidl
@@ -16,14 +16,14 @@
package com.android.internal.telephony;
-import android.os.Bundle;
+import android.os.PersistableBundle;
/**
* Interface used to interact with the CarrierConfigLoader
*/
interface ICarrierConfigLoader {
- Bundle getConfigForSubId(int subId);
+ PersistableBundle getConfigForSubId(int subId);
void reloadCarrierConfigForSubId(int subId);
diff --git a/telephony/java/android/telephony/CarrierConfigManager.java b/telephony/java/android/telephony/CarrierConfigManager.java
index 299c7c4..2caa83c 100644
--- a/telephony/java/android/telephony/CarrierConfigManager.java
+++ b/telephony/java/android/telephony/CarrierConfigManager.java
@@ -20,7 +20,7 @@ import com.android.internal.telephony.ICarrierConfigLoader;
import android.annotation.SystemApi;
import android.content.Context;
-import android.os.Bundle;
+import android.os.PersistableBundle;
import android.os.RemoteException;
import android.os.ServiceManager;
@@ -232,10 +232,10 @@ public class CarrierConfigManager {
private final static String TAG = "CarrierConfigManager";
/** The default value for every variable. */
- private final static Bundle sDefaults;
+ private final static PersistableBundle sDefaults;
static {
- sDefaults = new Bundle();
+ sDefaults = new PersistableBundle();
sDefaults.putBoolean(BOOL_ADDITIONAL_CALL_SETTING, true);
sDefaults.putBoolean(BOOL_ALLOW_EMERGENCY_NUMBERS_IN_CALL_LOG, false);
sDefaults.putBoolean(BOOL_ALLOW_LOCAL_DTMF_TONES, true);
@@ -276,10 +276,10 @@ public class CarrierConfigManager {
* values.
*
* @param subId the subscription ID, normally obtained from {@link SubscriptionManager}.
* @return A {@link Bundle} containing the config for the given subId, or default values for an
* invalid subId.
*/
- public Bundle getConfigForSubId(int subId) {
+ public PersistableBundle getConfigForSubId(int subId) {
try {
return getICarrierConfigLoader().getConfigForSubId(subId);
} catch (RemoteException ex) {
@@ -297,7 +297,7 @@ public class CarrierConfigManager {
*
* @see #getConfigForSubId
*/
- public Bundle getConfig() {
+ public PersistableBundle getConfig() {
return getConfigForSubId(SubscriptionManager.getDefaultSubId());
}
@@ -349,8 +349,8 @@ public class CarrierConfigManager {
* @hide
*/
@SystemApi
- public static Bundle getDefaultConfig() {
- return new Bundle(sDefaults);
+ public static PersistableBundle getDefaultConfig() {
+ return new PersistableBundle(sDefaults);
}
/** @hide */
@@ -276,10 +276,10 @@ public class CarrierConfigManager {
*
* @param subId the subscription ID, normally obtained from {@link SubscriptionManager}.
- * @return A {@link Bundle} containing the config for the given subId, or default values for an
- * invalid subId.
+ * @return A {@link PersistableBundle} containing the config for the given subId, or default
+ * values for an invalid subId.
*/